The model object (S4) class component for an implementation of the range bagging species distribution modelling (SDM) method (Drake, 2015).
Slots
methodSDM method: "rangebag".
variablesList of climate (or environmental) variable names.
presenceThe selected climate data corresponding to occurrences points.
coordinatesThe coordinates for the selected climate data.
ch_modelsA list of convex hull models (vertices).
References
Drake, J. M. (2015). Range bagging: a new method for ecological niche modelling from presence-only data. Journal of the Royal Society Interface, 12(107), 20150086. doi:10.1098/rsif.2015.0086